"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormTag = void 0;
const StringBuffer_js_1 = require("../util/StringBuffer.js");
const TagSupport_js_1 = require("../util/TagSupport.js");
const TagUtils_js_1 = require("../util/TagUtils.js");
const BaseHandlerTag_js_1 = require("./BaseHandlerTag.js");
/**
 * <html:form>
 *
 * @see https://github.com/apache/struts1/blob/trunk/taglib/src/main/java/org/apache/struts/taglib/html/FormTag.java
 */
class FormTag extends TagSupport_js_1.TagSupport {
    render() {
        const start = this._doStartTag();
        const body = this.getBody();
        const end = this._doEndTag();
        return this.tag.app.concat(start, body, end);
    }
    /**
     * Render the beginning of this form.
     */
    _doStartTag() {
        // Look up the form bean name, scope, and type if necessary
        this.lookup();
        // Create an appropriate "form" element based on our parameters
        const results = new StringBuffer_js_1.StringBuffer();
        results.append(this.renderFormStartElement());
        results.append(this.renderToken());
        this.initFormBean();
        return results.toString();
    }
    /**
     * Render the end of this form.
     */
    _doEndTag() {
        const { attr } = this;
        // Render a tag representing the end of our current form
        const results = new StringBuffer_js_1.StringBuffer("</form>");
        // Render JavaScript to set the input focus if required
        if (attr.focus) {
            results.append(this.renderFocusJavascript());
        }
        return results.toString();
    }
    /**
     * Locate or create the bean associated with our form.
     */
    initFormBean() {
        // TODO
    }
    /**
     * Generates the opening <code>&lt;form&gt;</code> element with
     * appropriate attributes.
     */
    renderFormStartElement() {
        const { attr } = this;
        const results = new StringBuffer_js_1.StringBuffer("<form");
        // render attributes
        this.renderName(results);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "method", attr.method || "post");
        this.renderAction(results);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "accept-charset", attr.acceptCharset);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "class", attr.styleClass);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "dir", attr.dir);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "enctype", attr.enctype);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "lang", attr.lang);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "onreset", attr.onreset);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "onsubmit", attr.onsubmit);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "style", attr.style);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "target", attr.target);
        // Hook for additional attributes
        this.renderOtherAttributes(results);
        results.append(">");
        return results.toString();
    }
    /**
     * Renders the name of the form.  If XHTML is set to true, the name will
     * be rendered as an 'id' attribute, otherwise as a 'name' attribute.
     */
    renderName(results) {
        const { attr } = this;
        if (this.isXhtml()) {
            (0, BaseHandlerTag_js_1.prepareAttribute)(results, "id", this.beanName);
        }
        else {
            (0, BaseHandlerTag_js_1.prepareAttribute)(results, "name", this.beanName);
            (0, BaseHandlerTag_js_1.prepareAttribute)(results, "id", attr.styleId);
        }
    }
    /**
     * Renders the action attribute
     */
    renderAction(results) {
        const { attr } = this;
        const calcAction = attr.action || this.postbackAction;
        results.append(" action=\"");
        results.append(TagUtils_js_1.TagUtils.getInstance().filter(calcAction));
        results.append("\"");
    }
    /**
     * 'Hook' to enable this tag to be extended and additional attributes
     * added.
     */
    renderOtherAttributes(_) {
        // NOP
    }
    /**
     * Generates a hidden input field with token information, if any. The
     * field is added within a div element for HTML 4.01 Strict compliance.
     */
    renderToken() {
        return; // TODO
    }
    /**
     * Generates javascript to set the initial focus to the form element given
     * in the tag's "focus" attribute.
     */
    renderFocusJavascript() {
        const { lineEnd } = FormTag;
        const { attr } = this;
        const isXhtml = this.isXhtml();
        const results = new StringBuffer_js_1.StringBuffer();
        results.append(lineEnd);
        results.append("<script type=\"text/javascript\"");
        if (!isXhtml && attr.scriptLanguage) {
            results.append(" language=\"JavaScript\"");
        }
        results.append(">");
        results.append(lineEnd);
        // xhtml content should emit CDATA section
        // but html content should use the browser hiding trick
        results.append(isXhtml ? "//<![CDATA[" : "<!--");
        results.append(lineEnd);
        // Construct the index if needed and insert into focus statement
        let index;
        if (attr.focusIndex) {
            const sb = new StringBuffer_js_1.StringBuffer("[");
            sb.append(attr.focusIndex);
            sb.append("]");
            index = sb.toString();
        }
        // Construct the control name that will receive focus.
        const focusControl = new StringBuffer_js_1.StringBuffer("document.forms[\"");
        focusControl.append(this.beanName);
        focusControl.append("\"].elements[\"");
        focusControl.append(attr.focus);
        focusControl.append("\"]");
        focusControl.append(index);
        results.append("  var focusControl = ");
        results.append(focusControl.toString());
        results.append(";");
        results.append(lineEnd);
        results.append(lineEnd);
        results.append("  if (focusControl != null && ");
        results.append("focusControl.type != \"hidden\" && ");
        results.append("!focusControl.disabled && ");
        results.append("focusControl.style.display != \"none\") {");
        results.append(lineEnd);
        results.append("     focusControl");
        results.append(".focus();");
        results.append(lineEnd);
        results.append("  }");
        results.append(lineEnd);
        results.append("//");
        results.append(isXhtml ? "]]>" : "-->");
        results.append(lineEnd);
        results.append("</script>");
        results.append(lineEnd);
        return results.toString();
    }
    /**
     * Look up values for the <code>name</code>, <code>scope</code>, and
     * <code>type</code> properties if necessary.
     */
    lookup() {
        // TODO
    }
    isXhtml() {
        return false;
    }
}
exports.FormTag = FormTag;
FormTag.lineEnd = "\n";
